/******************************************************************************
* File Name:   main.c
*
* Description: This is the source code for the XMC MCU: UART Transmit Example
*              for ModusToolbox. This code example demonstrates simple UART
*              communication by printing a "Hello World" message on a terminal
*              and blinking an LED. 
*
* Related Document: See README.md
*
******************************************************************************
*
* Copyright (c) 2021, Infineon Technologies AG
* All rights reserved.                        
*                                             
* Boost Software License - Version 1.0 - August 17th, 2003
* 
* Permission is hereby granted, free of charge, to any person or organization
* obtaining a copy of the software and accompanying documentation covered by
* this license (the "Software") to use, reproduce, display, distribute,
* execute, and transmit the Software, and to prepare derivative works of the
* Software, and to permit third-parties to whom the Software is furnished to
* do so, all subject to the following:
* 
* The copyright notices in the Software and this entire statement, including
* the above license grant, this restriction and the following disclaimer,
* must be included in all copies of the Software, in whole or in part, and
* all derivative works of the Software, unless such copies or derivative
* works are solely in the form of machine-executable object code generated by
* a source language processor.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
* SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
* FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
* DEALINGS IN THE SOFTWARE.
*                                                                              
*****************************************************************************/

#include "cybsp.h"
#include "cy_utils.h"
#include "xmc_gpio.h"
#include "xmc_uart.h"
#include <stdio.h>

/*******************************************************************************
* Defines
*******************************************************************************/

/* Declarations for LED toggle and UART transmission timing */
#define TICKS_PER_SECOND        1000
#define TICKS_WAIT              1000

/*******************************************************************************
* Global Variables
*******************************************************************************/
/* Declaration of array to store the message to be transmitted */
const uint8_t message[] = "Hello world!!\r\n";
const uint8_t message2[] = "Hello world2!!\r\n";
const uint8_t message3[] = "Hello world3!!\r\n";
const uint8_t clear_screen[] = "\x1b[2J\x1b[;H";

/*******************************************************************************
* Function Name: SysTick_Handler
********************************************************************************
* Summary:
* Function called by system timer every millisecond. It toggles an LED and sends
* the message via UART.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void SysTick_Handler(void)
{
    static uint32_t ticks = 0;
    uint32_t index;

    ticks++;
    if (ticks == TICKS_WAIT)
    { 
        /* Toggle the LED */
        XMC_GPIO_ToggleOutput(CYBSP_USER_LED_PORT, CYBSP_USER_LED_PIN);

        for (index = 0; index < sizeof(message2) - 1; index++)
        {
            /* Send a message via UART periodically */
            XMC_UART_CH_Transmit(CYBSP_DEBUG_UART_HW, message2[index]);
        }

        for (index = 0; index < sizeof(message2) - 1; index++)
        {
            /* Send a message via UART periodically */
            XMC_UART_CH_Transmit(usr_urat_HW, message2[index]);
        }
        printf("MESSAGE SENT\r\n\n");
        ticks = 0;
    }
}
/*******************************************************************************
* Function Name: USIC0_0_IRQHandler
********************************************************************************
* Summary:
* Receive handling IRQ . The function called everytime the number of elements
* in the RX FIFO exceeds above Rx FIFO Limit (set to seven).
* The function is used to read the RX FIFO until it is empty and set a flag
* when all the data has been received.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void xmc_read_byte(void){
	//if there is a char avaliable, return 1.  If there isn't return 0
	uint16_t rxData = 0x0000;

    uint32_t index;

	//check flags for recieved byte
	if(
	(XMC_UART_CH_GetStatusFlag(XMC_UART1_CH0) & (XMC_UART_CH_STATUS_FLAG_RECEIVE_INDICATION | XMC_UART_CH_STATUS_FLAG_ALTERNATIVE_RECEIVE_INDICATION)) != 0){

		rxData = XMC_UART_CH_GetReceivedData(XMC_UART1_CH0);
		//set the data to be rxData
		if(rxData == 0x00){  //do nothing if it's a null

		    for (index = 0; index < sizeof(message3) - 1; index++)
		    {
		        /* Send a message via UART periodically */
		        XMC_UART_CH_Transmit(CYBSP_DEBUG_UART_HW, message3[index]);
		    }

		    for (index = 0; index < sizeof(message2) - 1; index++)
		    {
		        /* Send a message via UART periodically */
		        XMC_UART_CH_Transmit(usr_urat_HW, message2[index]);
		    }
			//return 0;
		}
		XMC_UART_CH_Transmit(usr_urat_HW, rxData);
		//clear the recieved byte flags!
		XMC_UART_CH_ClearStatusFlag(XMC_UART0_CH0,XMC_UART_CH_STATUS_FLAG_RECEIVE_INDICATION | XMC_UART_CH_STATUS_FLAG_ALTERNATIVE_RECEIVE_INDICATION );

		//*data = rxData;
		//return 1;
	}

	//return 0;
}
void USIC1_0_IRQHandler(void)
{

    uint32_t index;

    for (index = 0; index < sizeof(message2) - 1; index++)
    {
        /* Send a message via UART periodically */
        XMC_UART_CH_Transmit(CYBSP_DEBUG_UART_HW, message2[index]);
    }

    for (index = 0; index < sizeof(message) - 1; index++)
    {
        /* Send a message via UART periodically */
        XMC_UART_CH_Transmit(usr_urat_HW, message[index]);
    }
	xmc_read_byte();

}
/*******************************************************************************
* Function Name: main
********************************************************************************
* Summary:
* This is the main function. It performs the following tasks:
*  1. Initial setup of device.
*  2. Starts the UART peripheral
*  3. Enables the system timer
*
* Parameters:
*  none
*
* Return:
*  int
*
*******************************************************************************/

/* Set interrupt priority for the USIC0_1_IRQn */
#define USIC1_0_IRQn_PRIORITY           62
int main(void)
{    
    cy_rslt_t result;
    uint32_t index;

    /* Initialize the device and board peripherals */
    result = cybsp_init();

    if (result != CY_RSLT_SUCCESS)
    {
        CY_ASSERT(0);
    }

    /* Start the UART peripheral*/ 
    XMC_UART_CH_Start(CYBSP_DEBUG_UART_HW);
    XMC_UART_CH_Start(usr_urat_HW);

    /* Send a message to clear the screen */
    for (index = 0; index < sizeof(clear_screen) - 1; index++)
    {
        XMC_UART_CH_Transmit(CYBSP_DEBUG_UART_HW, clear_screen[index]);
    }

    /* Send a message to clear the screen */
    for (index = 0; index < sizeof(clear_screen) - 1; index++)
    {
        XMC_UART_CH_Transmit(usr_urat_HW, clear_screen[index]);
    }

    for (index = 0; index < sizeof(message) - 1; index++)
    {
        /* Send a message via UART periodically */
        XMC_UART_CH_Transmit(CYBSP_DEBUG_UART_HW, message[index]);
    }

    for (index = 0; index < sizeof(message2) - 1; index++)
    {
        /* Send a message via UART periodically */
        XMC_UART_CH_Transmit(usr_urat_HW, message2[index]);
    }

    /* Enable system timer */
    //SysTick_Config(SystemCoreClock / TICKS_PER_SECOND);
    NVIC_EnableIRQ(USIC1_0_IRQn);
    NVIC_SetPriority(USIC1_0_IRQn, USIC1_0_IRQn_PRIORITY);

    while(1)
    {
        /* Infinite loop */
    	//xmc_read_byte();
    }
}

/* [] END OF FILE */
